@@ -360,7 +360,7 @@ class DexcellSender(object):
             'serviceNetworkId': int(serviceMessage.service),
             'value': float(serviceMessage.value),
             'seqNum': int(serviceMessage.seqnum),
-            'timeStamp': serviceMessage.timestamp
+            'timeStamp': serviceMessage.timestamp.isoformat()
         }
         data = {}
         data['msg'], total_service = self.pack_service_messages(reading)
@@ -381,7 +381,7 @@ class DexcellSender(object):
                 'serviceNetworkId': int(serviceMessage.service),
                 'value': float(serviceMessage.value),
                 'seqNum': int(serviceMessage.seqnum),
-                'timeStamp': serviceMessage.timestamp
+                'timeStamp': serviceMessage.timestamp.isoformat()
             }
             readings.append(reading)
         data = {}
